from jolliCode import Multiplot
from jolliCode import Open
from jolliCode import stdout2devnull
from jolliCode import get_globals

test = "test"

__all__ = [
    "Multiplot",
    "Open",
    "stdout2devnull",
    "get_globals",
    "test",
]